@@ -2,7 +2,7 @@
 from zeam.form.base import *
 from zeam.form.composed.form import ComposedForm, SubForm, SubFormGroup
 
-from grokcore.viewlet import view, order
+from grokcore.view import view, order
 
 from zeam.form.composed.interfaces import IZeamFormComposedAPI
 __all__ = list(IZeamFormComposedAPI)
